@@ -1,10 +1,10 @@
+from tempfile import NamedTemporaryFile
 from typing import Any, Dict
 
 from minio import Minio
-from pydantic.types import UUID4
 from vaex.dataframe import DataFrame
 
-from dataquality import config
+from dataquality.core._config import config
 
 
 class ObjectStore:
@@ -27,15 +27,13 @@ class ObjectStore:
 
     def create_project_run_object(
         self,
-        project_id: UUID4,
-        run_id: UUID4,
         object_name: str,
         file_path: str,
         content_type: str = "application/octet-stream",
     ) -> None:
         self.minio_client.fput_object(
             self.ROOT_BUCKET_NAME,
-            f"{project_id}/{run_id}/{object_name}",
+            object_name,
             file_path=file_path,
             content_type=content_type,
         )
@@ -44,14 +42,12 @@ class ObjectStore:
         self, df: DataFrame, object_name: str
     ) -> None:
         """Uploads a Vaex dataframe to Minio at the specified object_name location"""
-        minio_path = f"s3://{self.ROOT_BUCKET_NAME}/{object_name}"
-        df.export_arrow(
-            minio_path,
-            fs_options=self.get_fs_options(),
-            parallel=True,
-            reduce_large=True,
-            as_stream=True,
-        )
+        with NamedTemporaryFile(suffix=".hdf5") as f:
+            df.export(f.name, progress="vaex")
+            self.create_project_run_object(
+                object_name=object_name,
+                file_path=f.name,
+            )
 
     def get_fs_options(self) -> Dict[str, Any]:
         return dict(
