@@ -4,7 +4,10 @@ from typing import Callable, Dict
 
 import requests
 
-from dataquality.core.config import AuthMethod, Config, _Config, config
+from dataquality.clients import api_client
+from dataquality.core._config import AuthMethod, Config, config
+from dataquality.exceptions import GalileoException
+from dataquality.schemas import RequestType, Route
 
 GALILEO_AUTH_METHOD = "GALILEO_AUTH_METHOD"
 
@@ -39,40 +42,30 @@ class _Auth:
             return
 
         access_token = res.json().get("access_token")
-        self.config.token = access_token
-        _config = _Config()
-        _config.write_config(self.config.json())
+        config.token = access_token
+        config.update_file_config()
 
     def email_token_present_and_valid(self, config: Config) -> bool:
         return config.auth_method == "email" and self.valid_current_user(config)
 
     def valid_current_user(self, config: Config) -> bool:
         if config.token:
-            return (
-                requests.get(
-                    f"{self.config.api_url}/current_user",
-                    headers={"Authorization": f"Bearer {config.token}"},
-                ).status_code
-                == 200
-            )
+            try:
+                api_client.make_request(
+                    RequestType.GET, url=f"{config.api_url}/{Route.current_user}"
+                )
+                return True
+            except GalileoException:
+                return False
         else:
             return False
 
-    def get_current_user(self, config: Config) -> Dict:
-        if not config.token:
-            raise Exception("Current user is not set!")
-
-        return requests.get(
-            f"{self.config.api_url}/current_user",
-            headers={"Authorization": f"Bearer {config.token}"},
-        ).json()
-
 
 def login() -> None:
     print("🔭 Logging you into Galileo\n")
     auth_methods = ",".join([am.value for am in AuthMethod])
     # Try auto auth config
-    auth_method = os.getenv(GALILEO_AUTH_METHOD)
+    auth_method = os.getenv(GALILEO_AUTH_METHOD) or config.auth_method
     if not auth_method or auth_method.lower() not in list(AuthMethod):
         auth_method = input(
             "🔐 How would you like to login? \n"
@@ -92,7 +85,7 @@ def login() -> None:
     config.auth_method = AuthMethod(auth_method)
     _auth = _Auth(config=config, auth_method=config.auth_method)
     _auth.auth_methods()[config.auth_method]()
-    current_user_email = _auth.get_current_user(config).get("email")
+    current_user_email = api_client.get_current_user().get("email")
     if not current_user_email:
         return
     config.current_user = current_user_email
