@@ -1,103 +1,51 @@
 import os
 import warnings
-from typing import Dict, List, Optional
+from typing import Dict, Optional
 
-import requests
 from pydantic.types import UUID4
 
-from dataquality import config
-from dataquality.core.auth import _Auth
-from dataquality.core.log import JsonlLogger
+from dataquality.clients import api_client
+from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
-from dataquality.schemas import Route
-from dataquality.utils.auth import headers
+from dataquality.loggers import BaseGalileoLogger
+from dataquality.schemas.task_type import TaskType
 from dataquality.utils.name import random_name
 
 
 class _Init:
-    def create_project(self, data: Dict) -> Dict:
-        if not config.token:
-            raise GalileoException("Token not present, please log in!")
-        req = requests.post(
-            f"{config.api_url}/{Route.projects}",
-            json=data,
-            headers=headers(config.token),
-        )
-        return req.json()
-
-    def create_project_run(self, project_id: UUID4, data: Dict) -> Dict:
-        if not config.token:
-            raise GalileoException("Token not present, please log in!")
-        req = requests.post(
-            f"{config.api_url}/{Route.projects}/{project_id}/runs",
-            json=data,
-            headers=headers(config.token),
-        )
-        return req.json()
-
-    def get_user_projects(self) -> List[Dict]:
-        user_id = self.get_user_id()
-        req = requests.get(
-            f"{config.api_url}/{Route.users}/{user_id}/projects",
-            headers=headers(config.token),
-        )
-        return req.json()
-
     def get_project_by_name_for_user(self, project_name: str) -> Dict:
-        projects = self.get_user_projects()
-        name_project = {project["name"]: project for project in projects}
-        return name_project.get(project_name, {})
-
-    def get_runs_from_project_for_user(self, project_name: str) -> Dict:
-        """Gets the runs for a given project for a given user"""
-        project = self.get_project_by_name_for_user(project_name)
-        if not project:
-            return {}
-        pid = project.get("id")
-        req = requests.get(
-            f"{config.api_url}/{Route.projects}/{pid}/runs",
-            headers=headers(config.token),
-        )
-        return req.json()
+        return api_client.get_project_by_name(project_name)
 
     def get_project_run_by_name_for_user(
         self, project_name: str, run_name: str
     ) -> Dict:
-        runs = self.get_runs_from_project_for_user(project_name)
-        name_run = {run["name"]: run for run in runs}
-        return name_run.get(run_name, {})
-
-    def get_run_from_project(self, project_id: UUID4, run_id: UUID4) -> Dict:
-        if not config.token:
-            raise GalileoException("Token not present, please log in!")
-        return requests.get(
-            f"{config.api_url}/{Route.projects}/{project_id}/runs/{run_id}",
-            headers=headers(config.token),
-        ).json()
-
-    def get_user_id(self) -> UUID4:
-        if not config.token:
-            raise GalileoException("Token not present, please log in!")
-        _auth = _Auth(config=config, auth_method=config.auth_method)
-        return _auth.get_current_user(config)["id"]
+        return api_client.get_project_run_by_name(project_name, run_name)
 
     def _initialize_new_project(self, project_name: str) -> Dict:
         print(f"✨ Initializing project {project_name}")
-        body = {"name": project_name}
-        return self.create_project(body)
+        try:
+            return api_client.create_project(project_name=project_name)
+        except GalileoException as e:
+            if "A project with this name already exists" in str(e):
+                return api_client.get_project_by_name(project_name)
+            else:
+                raise e
 
-    def _initialize_run_for_project(self, project_id: UUID4, run_name: str) -> Dict:
+    def _initialize_run_for_project(
+        self, project_name: str, run_name: str, task_type: TaskType
+    ) -> Dict:
         print(f"🏃‍♂️ Starting run {run_name}")
-        body = {"name": run_name}
-        return self.create_project_run(project_id, body)
+        return api_client.create_run(project_name, run_name, task_type)
 
     def create_log_file_dir(self, project_id: UUID4, run_id: UUID4) -> None:
-        write_output_dir = f"{JsonlLogger.LOG_FILE_DIR}/{project_id}/{run_id}"
+        write_output_dir = f"{BaseGalileoLogger.LOG_FILE_DIR}/{project_id}/{run_id}"
         if not os.path.exists(write_output_dir):
             os.makedirs(write_output_dir)
 
 
-def init(project_name: Optional[str] = None, run_name: Optional[str] = None) -> None:
+def init(
+    task_type: str, project_name: Optional[str] = None, run_name: Optional[str] = None
+) -> None:
     """
     Start a run
 
@@ -107,6 +55,8 @@ def init(project_name: Optional[str] = None, run_name: Optional[str] = None) ->
     Optionally provide project and run names to create a new project/run or restart
     existing ones.
 
+    :param task_type: The task type for modeling. This must be one of the valid
+    `dataquality.schemas.task_type.TaskType` options
     :param project_name: The project name. If not passed in, a random one will be
     generated. If provided, and the project does not exist, it will be created. If it
     does exist, it will be set.
@@ -114,14 +64,20 @@ def init(project_name: Optional[str] = None, run_name: Optional[str] = None) ->
     generated. If provided, and the project does not exist, it will be created. If it
     does exist, it will be set.
     """
+    if not config.token:
+        raise GalileoException(
+            "You must log in before calling init. Call dataquality.login()"
+        )
     _init = _Init()
-    config.labels = None
+    BaseGalileoLogger.validate_task(task_type)
+    task_type = TaskType[task_type]
+    config.task_type = task_type
     if not project_name and not run_name:
         # no project and no run id, start a new project and start a new run
         project_name, run_name = random_name(), random_name()
         project_response = _init._initialize_new_project(project_name=project_name)
         run_response = _init._initialize_run_for_project(
-            project_id=project_response["id"], run_name=run_name
+            project_name=project_name, run_name=run_name, task_type=task_type
         )
         config.current_project_id = project_response["id"]
         config.current_run_id = run_response["id"]
@@ -133,7 +89,7 @@ def init(project_name: Optional[str] = None, run_name: Optional[str] = None) ->
             run_name = random_name()
             print(f"📡 Retrieved project, {project_name}, and starting a new run")
             run_response = _init._initialize_run_for_project(
-                project_id=project["id"], run_name=run_name
+                project_name=project_name, run_name=run_name, task_type=task_type
             )
             config.current_project_id = project["id"]
             config.current_run_id = run_response["id"]
@@ -146,27 +102,32 @@ def init(project_name: Optional[str] = None, run_name: Optional[str] = None) ->
             run_name = random_name()
             project_response = _init._initialize_new_project(project_name=project_name)
             run_response = _init._initialize_run_for_project(
-                project_id=project_response["id"], run_name=run_name
+                project_name=project_name, run_name=run_name, task_type=task_type
             )
             config.current_project_id = project_response["id"]
             config.current_run_id = run_response["id"]
     elif project_name and run_name:
-        # If the project and run exist, connect to them
-        print(f"📡 Retrieving existing run from project, {project_name}")
         project = _init.get_project_by_name_for_user(project_name)
         # if project actually exists, get the run
         if project.get("name"):
+            # If the project and run exist, connect to them
+            print(f"📡 Retrieving run from existing project, {project_name}")
             run = _init.get_project_run_by_name_for_user(
                 project["name"], run_name=run_name
             )
             if run.get("id"):
                 config.current_project_id = project["id"]
                 config.current_run_id = run["id"]
+                warnings.warn(
+                    f"Project run {project_name}/{run_name} already exists. "
+                    "Logging and calling finish will overwrite all data in "
+                    "the server"
+                )
                 print(f"🛰 Connected to project, {project_name}, and run, {run_name}.")
             else:
                 # If the run does not exist, create it
                 run_response = _init._initialize_run_for_project(
-                    project["id"], run_name
+                    project_name, run_name, task_type
                 )
                 config.current_project_id = project["id"]
                 config.current_run_id = run_response["id"]
@@ -179,7 +140,7 @@ def init(project_name: Optional[str] = None, run_name: Optional[str] = None) ->
             print(f"💭 Project {project_name} was not found.")
             project_response = _init._initialize_new_project(project_name=project_name)
             run_response = _init._initialize_run_for_project(
-                project_id=project_response["id"], run_name=run_name
+                project_name=project_name, run_name=run_name, task_type=task_type
             )
             config.current_project_id = project_response["id"]
             config.current_run_id = run_response["id"]
